package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.VideoDataMapper;
import com.ruoyi.system.domain.VideoData;
import com.ruoyi.system.service.IVideoDataService;

/**
 * videoService业务层处理
 * 
 * @author ljx
 * @date 2024-08-05
 */
@Service
public class VideoDataServiceImpl implements IVideoDataService 
{
    @Autowired
    private VideoDataMapper videoDataMapper;

    /**
     * 查询video
     * 
     * @param id video主键
     * @return video
     */
    @Override
    public VideoData selectVideoDataById(Long id)
    {
        return videoDataMapper.selectVideoDataById(id);
    }

    /**
     * 查询video列表
     * 
     * @param videoData video
     * @return video
     */
    @Override
    public List<VideoData> selectVideoDataList(VideoData videoData)
    {
        return videoDataMapper.selectVideoDataList(videoData);
    }

    /**
     * 新增video
     * 
     * @param videoData video
     * @return 结果
     */
    @Override
    public int insertVideoData(VideoData videoData)
    {
        return videoDataMapper.insertVideoData(videoData);
    }

    /**
     * 修改video
     * 
     * @param videoData video
     * @return 结果
     */
    @Override
    public int updateVideoData(VideoData videoData)
    {
        return videoDataMapper.updateVideoData(videoData);
    }

    /**
     * 批量删除video
     * 
     * @param ids 需要删除的video主键
     * @return 结果
     */
    @Override
    public int deleteVideoDataByIds(Long[] ids)
    {
        return videoDataMapper.deleteVideoDataByIds(ids);
    }

    /**
     * 删除video信息
     * 
     * @param id video主键
     * @return 结果
     */
    @Override
    public int deleteVideoDataById(Long id)
    {
        return videoDataMapper.deleteVideoDataById(id);
    }
}
